@@ -2,7 +2,9 @@ package WebService::PayPal::PaymentsAdvanced::Mocker::SilentPOST;
 
 use Moo;
 
-our $VERSION = '0.000021';
+use namespace::autoclean;
+
+our $VERSION = '0.000022';
 
 use Types::Common::String qw( NonEmptyStr );
 use Types::Standard qw( InstanceOf );
@@ -247,13 +249,15 @@ sub _set_defaults {
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WebService::PayPal::PaymentsAdvanced::Mocker::SilentPOST - Easily mock Silent POST transactions
 
 =head1 VERSION
 
-version 0.000021
+version 0.000022
 
 =head1 SYNOPSIS
 
@@ -299,13 +303,17 @@ validation enabled you'll either need to spoof the originating IP of the
 request or disable the IP validation in test mode.  I'd encourage you to do
 the former, if at all possible.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/webservice-paypal-paymentsadvanced/issues>.
+
 =head1 AUTHOR
 
 Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by MaxMind, Inc.
+This software is copyright (c) 2017 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
