@@ -2,7 +2,9 @@ package WebService::PayPal::PaymentsAdvanced::Response;
 
 use Moo;
 
-our $VERSION = '0.000021';
+use namespace::autoclean;
+
+our $VERSION = '0.000022';
 
 use List::AllUtils qw( any );
 use Types::Common::String qw( NonEmptyStr );
@@ -42,7 +44,7 @@ sub BUILD {
     my $result = $self->params->{RESULT};
 
     return
-        if Int->check($result)
+        if Int()->check($result)
         && ( any { $result == $_ } @{ $self->_nonfatal_result_codes } );
 
     if ( $result && $result == 1 ) {
@@ -62,13 +64,15 @@ sub BUILD {
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WebService::PayPal::PaymentsAdvanced::Response - Generic response object
 
 =head1 VERSION
 
-version 0.000021
+version 0.000022
 
 =head1 SYNOPSIS
 
@@ -107,13 +111,17 @@ L<WebService::PayPal::PaymentsAdvanced::Response::FromHTTP>,
 L<WebService::PayPal::PaymentsAdvanced::Response::FromRedirect>,
 L<WebService::PayPal::PaymentsAdvanced::Response::FromSilentPost>,
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/webservice-paypal-paymentsadvanced/issues>.
+
 =head1 AUTHOR
 
 Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by MaxMind, Inc.
+This software is copyright (c) 2017 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
