@@ -2,7 +2,9 @@ package WebService::PayPal::PaymentsAdvanced::Response::FromSilentPOST;
 
 use Moo;
 
-our $VERSION = '0.000021';
+use namespace::autoclean;
+
+our $VERSION = '0.000022';
 
 use List::AllUtils qw( any );
 use MooX::HandlesVia;
@@ -72,13 +74,15 @@ sub _build_ip_address_is_verified {
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WebService::PayPal::PaymentsAdvanced::Response::FromSilentPOST - Response object generated via Silent POST params
 
 =head1 VERSION
 
-version 0.000021
+version 0.000022
 
 =head1 DESCRIPTION
 
@@ -116,13 +120,17 @@ This module will throw a
 L<WebService::PayPal::PaymentsAdvanced::Error::IPVerification> exception if
 the provided IP address cannot be validated.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/webservice-paypal-paymentsadvanced/issues>.
+
 =head1 AUTHOR
 
 Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by MaxMind, Inc.
+This software is copyright (c) 2017 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
