@@ -2,7 +2,9 @@ package WebService::PayPal::PaymentsAdvanced::Response::FromSilentPOST::PayPal;
 
 use Moo;
 
-our $VERSION = '0.000021';
+use namespace::autoclean;
+
+our $VERSION = '0.000022';
 
 extends 'WebService::PayPal::PaymentsAdvanced::Response::FromSilentPOST';
 
@@ -12,13 +14,15 @@ with 'WebService::PayPal::PaymentsAdvanced::Role::HasPayPal';
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WebService::PayPal::PaymentsAdvanced::Response::FromSilentPOST::PayPal - Response class for PayPal Silent POST transactions
 
 =head1 VERSION
 
-version 0.000021
+version 0.000022
 
 =head1 DESCRIPTION
 
@@ -28,13 +32,17 @@ L<WebService::PayPal::PaymentsAdvanced::Response::FromSilentPOST> and includes
 the methods provided by
 L<WebService::PayPal::PaymentsAdvanced::Role::HasPayPal>.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/webservice-paypal-paymentsadvanced/issues>.
+
 =head1 AUTHOR
 
 Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by MaxMind, Inc.
+This software is copyright (c) 2017 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
