@@ -2,8 +2,11 @@ package WebService::PayPal::PaymentsAdvanced::Role::ClassFor;
 
 use Moo::Role;
 
-our $VERSION = '0.000021';
+use namespace::autoclean;
 
+our $VERSION = '0.000022';
+
+## no critic (ProhibitUnusedPrivateSubroutines)
 sub _class_for {
     my $self = shift;
     return 'WebService::PayPal::PaymentsAdvanced::' . shift;
