@@ -2,7 +2,9 @@ package WebService::PayPal::PaymentsAdvanced::Role::HasCreditCard;
 
 use Moo::Role;
 
-our $VERSION = '0.000021';
+use namespace::autoclean;
+
+our $VERSION = '0.000022';
 
 use Types::Common::Numeric qw( PositiveInt );
 use Types::Common::String qw( NonEmptyStr );
@@ -61,13 +63,15 @@ sub _build_card_expiration {
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WebService::PayPal::PaymentsAdvanced::Role::HasCreditCard - Role which provides methods specifically for credit card transactions
 
 =head1 VERSION
 
-version 0.000021
+version 0.000022
 
 =head2 card_type
 
@@ -92,13 +96,17 @@ The last four digits of the credit card.
 
 The id you will use in order to use this as a reference transaction (C<pnref>).
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/webservice-paypal-paymentsadvanced/issues>.
+
 =head1 AUTHOR
 
 Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by MaxMind, Inc.
+This software is copyright (c) 2017 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
