@@ -2,7 +2,9 @@ package WebService::PayPal::PaymentsAdvanced::Role::HasPayPal;
 
 use Moo::Role;
 
-our $VERSION = '0.000021';
+use namespace::autoclean;
+
+our $VERSION = '0.000022';
 
 use Types::Common::String qw( NonEmptyStr );
 
@@ -21,13 +23,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WebService::PayPal::PaymentsAdvanced::Role::HasPayPal - Role which provides methods specifically for PayPal transactions
 
 =head1 VERSION
 
-version 0.000021
+version 0.000022
 
 =head1 METHODS
 
@@ -35,13 +39,17 @@ version 0.000021
 
 The id you will use in order to use this as a reference transaction (C<BAID>).
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/webservice-paypal-paymentsadvanced/issues>.
+
 =head1 AUTHOR
 
 Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by MaxMind, Inc.
+This software is copyright (c) 2017 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
