@@ -2,7 +2,9 @@ package WebService::PayPal::PaymentsAdvanced::Role::HasTender;
 
 use Moo::Role;
 
-our $VERSION = '0.000021';
+use namespace::autoclean;
+
+our $VERSION = '0.000022';
 
 use Types::Standard qw( Bool StrictNum );
 
@@ -45,13 +47,15 @@ sub _build_is_paypal_transaction {
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WebService::PayPal::PaymentsAdvanced::Role::HasTender - Role which provides some methods describing a transaction
 
 =head1 VERSION
 
-version 0.000021
+version 0.000022
 
 =head2 amount
 
@@ -65,13 +69,17 @@ C<Boolean>.  Returns true if this is a credit card transaction.
 
 C<Boolean>.  Returns true if this is a PayPal transaction.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/webservice-paypal-paymentsadvanced/issues>.
+
 =head1 AUTHOR
 
 Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by MaxMind, Inc.
+This software is copyright (c) 2017 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
