@@ -2,7 +2,9 @@ package WebService::PayPal::PaymentsAdvanced::Role::HasTokens;
 
 use Moo::Role;
 
-our $VERSION = '0.000021';
+use namespace::autoclean;
+
+our $VERSION = '0.000022';
 
 use Types::Common::String qw( NonEmptyStr );
 
@@ -32,13 +34,15 @@ sub _build_secure_token_id {
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WebService::PayPal::PaymentsAdvanced::Role::HasTokens - Provides roles for dealing with secure tokens
 
 =head1 VERSION
 
-version 0.000021
+version 0.000022
 
 =head2 secure_token
 
@@ -48,13 +52,17 @@ Returns C<SECURETOKEN> param
 
 Returns C<SECURETOKENID> param
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/webservice-paypal-paymentsadvanced/issues>.
+
 =head1 AUTHOR
 
 Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by MaxMind, Inc.
+This software is copyright (c) 2017 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
